<?php

/**
 * @file
 * Important administration functions for the groupon module.
 */

/**
 * Implements of groupon_settings_form().
 */
function groupon_settings_form() {
  $form['groupon'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings For Groupon Module'),
    '#collapsible' => FALSE,
  );
  $form['groupon']['groupon_client_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Client ID'),
    '#required' => TRUE,
    '#description' => t('Enter your client id which will be provided by Groupon.'),
    '#default_value' => filter_xss_admin(variable_get('groupon_client_id')),
  );
  $form['groupon']['groupon_channel_id'] = array(
    '#type' => 'select',
    '#title' => t('Channel ID'),
    '#required' => TRUE,
    '#options' => array(
      'getaways' => 'Getaways',
      'goods' => 'Goods',
      'occasions' => 'Occasions',
    ),
    '#description' => 'Select channel id which will be provided by Groupon.',
    '#default_value' => variable_get('groupon_channel_id'),
  );
  $form['groupon']['groupon_division_id'] = array(
    '#type' => 'select',
    '#title' => t('Division ID'),
    '#required' => TRUE,
    '#options' => groupon_get_divisions(),
    '#description' => t('Select division id to show deals from specific division.'),
    '#default_value' => variable_get('groupon_division_id'),
  );
  $form['groupon_error'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings For Groupon Error Page'),
    '#collapsible' => FALSE,
  );
  $form['groupon_error']['groupon_error_message'] = array(
    '#type' => 'textarea',
    '#title' => t('Error Message'),
    '#required' => TRUE,
    '#description' => t('Enter error message for error page.'),
    '#default_value' => filter_xss_admin(variable_get('groupon_error_message')),
  );
  $form['groupon_error']['groupon_default_error_message'] = array(
    '#type' => 'select',
    '#title' => t('Default error message'),
    '#required' => FALSE,
    '#options' => array(0 => 'Disable', 1 => 'enable'),
    '#description' => t('You can enable or disable default error message.'),
    '#default_value' => variable_get('groupon_default_error_message'),
  );
  $form['groupon_sayings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings For Groupon Says Page'),
    '#collapsible' => FALSE,
  );
  $form['groupon_sayings']['groupon_says_limit'] = array(
    '#type' => 'select',
    '#title' => t('Limit'),
    '#required' => TRUE,
    '#options' => array(1 => '1', 2 => '2', 3 => '3', 4 => '4', 5 => '5'),
    '#description' => t('Select limit for groupon says page.'),
    '#default_value' => variable_get('groupon_says_limit'),
  );
  $form['groupon_sayings']['groupon_says_random'] = array(
    '#type' => 'select',
    '#title' => t('Random'),
    '#required' => FALSE,
    '#options' => array(0 => 'FALSE', 1 => 'TRUE'),
    '#description' => t('Select for groupon says list will be random or not.'),
    '#default_value' => variable_get('groupon_says_random'),
  );
  $form['groupon_block'] = array(
    '#type' => 'fieldset',
    '#title' => t('Settings For Groupon Blocks'),
    '#collapsible' => FALSE,
  );
  $form['groupon_block']['groupon_block_num_deals'] = array(
    '#type' => 'select',
    '#title' => t('Number of deals on block'),
    '#required' => FALSE,
    '#options' => array(0 => '1', 1 => '2', 2 => '3', 3 => '4', 4 => '5'),
    '#description' => t('Select numbers of deals you want to show on blocks.'),
    '#default_value' => variable_get('groupon_block_num_deals'),
  );
  return system_settings_form($form);
}

/**
 * Helper function to get divisions for admin settings.
 *
 * @return array
 *   Array of divisions.
 */
function groupon_get_divisions() {
  $groupon_divisions = array(
    "abbotsford" => "Abbotsford",
    "abilene" => "Abilene, TX",
    "akron-canton" => "Akron / Canton",
    "albany-capital-region" => "Albany / Capital Region",
    "albuquerque" => "Albuquerque",
    "allentown-reading" => "Allentown / Reading",
    "amarillo" => "Amarillo",
    "anchorage" => "Anchorage",
    "ann-arbor" => "Ann Arbor",
    "asheville" => "Asheville",
    "athens-ga" => "Athens, GA",
    "atlanta" => "Atlanta",
    "augusta" => "Augusta",
    "austin" => "Austin",
    "bakersfield" => "Bakersfield",
    "baltimore" => "Baltimore",
    "barrie" => "Barrie",
    "baton-rouge" => "Baton Rouge",
    "beaumont" => "Beaumont, TX",
    "billings" => "Billings / Bozeman",
    "birmingham" => "Birmingham",
    "bloomington-in" => "Bloomington, IN",
    "boise" => "Boise",
    "boston" => "Boston",
    "buffalo" => "Buffalo",
    "calgary" => "Calgary",
    "cape-breton" => "Cape Breton",
    "cedar-rapids-iowa-city" => "Cedar Rapids / Iowa City",
    "central-jersey" => "Central Jersey",
    "charleston" => "Charleston",
    "charleston-wv" => "Charleston, WV",
    "charlotte" => "Charlotte",
    "chattanooga" => "Chattanooga",
    "chicago" => "Chicago",
    "cincinnati" => "Cincinnati",
    "cleveland" => "Cleveland",
    "colorado-springs" => "Colorado Springs",
    "columbia" => "Columbia",
    "columbia-mo" => "Columbia, MO",
    "columbus" => "Columbus",
    "columbus-ga" => "Columbus GA",
    "corpus-christi" => "Corpus Christi",
    "dallas" => "Dallas",
    "dayton" => "Dayton",
    "daytona-beach" => "Daytona Beach",
    "denver" => "Denver",
    "des-moines" => "Des Moines",
    "detroit" => "Detroit",
    "edmonton" => "Edmonton",
    "el-paso" => "El Paso",
    "erie" => "Erie",
    "eugene" => "Eugene",
    "evansville" => "Evansville",
    "fairfield-county" => "Fairfield County",
    "fort-lauderdale" => "Fort Lauderdale",
    "fort-myers-cape-coral" => "Fort Myers / Cape Coral",
    "fort-wayne" => "Fort Wayne",
    "fort-worth" => "Fort Worth",
    "appleton" => "Fox Cities",
    "fresno" => "Fresno",
    "gainesville" => "Gainesville",
    "grand-rapids" => "Grand Rapids",
    "green-bay" => "Green Bay",
    "greenville" => "Greenville",
    "halifax" => "Halifax",
    "hampton-roads" => "Hampton Roads",
    "harrisburg" => "Harrisburg / Lancaster",
    "hartford" => "Hartford",
    "honolulu" => "Honolulu",
    "houston" => "Houston",
    "huntsville" => "Huntsville",
    "indianapolis" => "Indianapolis",
    "inland-empire" => "Inland Empire",
    "jackson" => "Jackson",
    "jacksonville" => "Jacksonville",
    "kalamazoo" => "Kalamazoo",
    "kansas-city" => "Kansas City",
    "kelowna" => "Kelowna",
    "kingston" => "Kingston / Belleville",
    "kitchener-waterloo" => "Kitchener - Waterloo",
    "knoxville" => "Knoxville",
    "lakeland" => "Lakeland",
    "lansing" => "Lansing",
    "las-vegas" => "Las Vegas",
    "lexington" => "Lexington",
    "lincoln" => "Lincoln",
    "little-rock" => "Little Rock",
    "london" => "London, ON",
    "long-island" => "Long Island",
    "los-angeles" => "Los Angeles",
    "louisville" => "Louisville",
    "lubbock" => "Lubbock",
    "macon" => "Macon",
    "madison" => "Madison",
    "memphis" => "Memphis",
    "miami" => "Miami",
    "midland-odessa" => "Midland / Odessa",
    "milwaukee" => "Milwaukee",
    "minneapolis-stpaul" => "Minneapolis / St Paul",
    "mobile-baldwin-county" => "Mobile / Baldwin County",
    "modesto" => "Modesto",
    "montgomery" => "Montgomery",
    "napa-sonoma" => "Napa / Sonoma",
    "naples" => "Naples",
    "nashville" => "Nashville",
    "new-orleans" => "New Orleans",
    "new-york" => "New York City",
    "north-jersey" => "North Jersey",
    "ocala" => "Ocala",
    "ogden" => "Ogden",
    "oklahoma-city" => "Oklahoma City",
    "omaha" => "Omaha",
    "orange-county" => "Orange County",
    "orlando" => "Orlando",
    "ottawa" => "Ottawa",
    "palm-beach" => "Palm Beach",
    "pensacola" => "Pensacola / Emerald Coast",
    "philadelphia" => "Philadelphia",
    "phoenix" => "Phoenix",
    "piedmont-triad" => "Piedmont Triad",
    "pittsburgh" => "Pittsburgh",
    "portland" => "Portland",
    "portland-me" => "Portland, ME",
    "providence" => "Providence",
    "raleigh-durham" => "Raleigh / Durham",
    "regina" => "Regina",
    "reno" => "Reno",
    "richmond" => "Richmond",
    "rio-grande-valley" => "Rio Grande Valley",
    "roanoke" => "Roanoke",
    "rochester" => "Rochester",
    "rockford" => "Rockford",
    "sacramento" => "Sacramento",
    "salem-or" => "Salem OR",
    "salt-lake-city" => "Salt Lake City",
    "san-angelo" => "San Angelo",
    "san-antonio" => "San Antonio",
    "san-diego" => "San Diego",
    "san-francisco" => "San Francisco",
    "san-jose" => "San Jose",
    "santa-barbara" => "Santa Barbara",
    "santa-clarita" => "Santa Clarita",
    "santa-cruz" => "Santa Cruz / Monterey",
    "saskatoon" => "Saskatoon",
    "savannah-hilton-head" => "Savannah / Hilton Head",
    "seattle" => "Seattle",
    "shreveport-bossier" => "Shreveport / Bossier",
    "sioux-falls" => "Sioux Falls",
    "south-bend" => "South Bend",
    "albany-ga" => "Southern Georgia",
    "spokane-coeur-dalene" => "Spokane / Coeur d'Alene",
    "springfield-mo" => "Springfield MO",
    "springfield-ma" => "Springfield, MA",
    "stcatharines-niagara" => "St Catharines-Niagara",
    "st-johns" => "St John's",
    "stlouis" => "St Louis",
    "stockton" => "Stockton",
    "sudbury" => "Sudbury / North Bay",
    "syracuse" => "Syracuse",
    "tallahassee" => "Tallahassee",
    "tampa-bay-area" => "Tampa Bay Area",
    "toledo" => "Toledo",
    "topeka-lawrence" => "Topeka / Lawrence",
    "greater-toronto-area" => "Toronto (GTA)",
    "tucson" => "Tucson",
    "tulsa" => "Tulsa",
    "vancouver" => "Vancouver",
    "ventura-county" => "Ventura County",
    "victoria" => "Victoria",
    "washington-dc" => "Washington DC",
    "westchester-county" => "Westchester County",
    "wichita" => "Wichita",
    "wilmington-newark" => "Wilmington-Newark",
    "windsor" => "Windsor",
    "winnipeg" => "Winnipeg",
    "worcester" => "Worcester",
    "youngstown" => "Youngstown",
  );
  return $groupon_divisions;
}
